==> SSOAP_0.2-1.tar.gz: SSOAP/man/SOAPServer.Rd <==
\name{SOAPServer}
\alias{SOAPServer}
\title{Create a SOAP server object}
\description{
  This is a constructor for the \code{SOAPServer} class
  which is used to identify the host, port and URL of a SOAP
  server.
}
\usage{
SOAPServer(host, url, port = 80, s = new(className))
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{host}{typically, the name of the host machine,
    e.g. \code{"www.omegahat.org"}.
    Alternatively, a complete URL (e.g. \code{http://www.omegahat.org/SOAP})
    may be given as the value for host and the individual
    parts are extracted from this.
  }
    \item{url}{the file/URL within the server that contains the SOAP
      server. If this is omitted, we attempt to find the value
    from the value of \code{host}.}
    \item{port}{the port number on which the server is listening.
      This is typically 80, the standard HTTP port. However, one can
      specify  this when creating the S server object to
      identify a different port. This is useful when testing
      a server since one can use a user-level port.}
    \item{s}{the object being created and initialized.
      Having this as an argument allows the caller to specify
      the class of the desired object and supply a partially initialized
      value and still get the ``standard'' initialization for the server
      object.
      \code{className} is computed in the body of the function and this
      mechanism works via lazy evaluation.
      }
}
\note{
  In the future, we will use a \code{SOAPConnection}
  class that builds on the server and maintains a
  connection to the server.
  The URL may get dropped from the server as we can use
  the same basic host and port combination with different
  URLs for different requests. Experience will give us
  a better handle on an appropriate interface.

  Also, we may store a server-specific, default SOAPAction value in the server.
}    
\value{
  An object of class \code{HTTPSOAPServer},
  \code{FTPSOAPServer} or \code{SOAPServer}.
  If the host is specified with an \code{ftp:} or \code{http:}
  prefix, an object of class \code{FTPSOAPServer} or
  \code{HTTPSOAPServer} respectively is returned.
  Otherwise, a generic \code{SOAPServer} is created.
}
\references{
  \url{http://www.w3.org/TR/SOAP/}
  \url{http://www.omegahat.org/SSOAP},
  \url{http://www.omegahat.org/bugs}.
}
\author{Duncan Temple Lang <duncan@research.bell-labs.com>}
\seealso{
 \code{\link{.SOAP}}
}

\examples{
SOAPServer("www.nanonull.com", "TimeService/TimeService.asmx")
}
\keyword{interface}
\keyword{connection}

==> SSOAP_0.2-2.tar.gz: SSOAP/man/SOAPServer.Rd <==
\name{SOAPServer}
\alias{SOAPServer}
\title{Create a SOAP server object}
\description{
  This is a constructor for the \code{SOAPServer} class
  which is used to identify the host, port and URL of a SOAP
  server.
}
\usage{
SOAPServer(host, url, port = NA, s = new(className))
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{host}{typically, the name of the host machine,
    e.g. \code{"www.omegahat.org"}.
    Alternatively, a complete URL (e.g. \code{http://www.omegahat.org/SOAP})
    may be given as the value for host and the individual
    parts are extracted from this.
  }
    \item{url}{the file/URL within the server that contains the SOAP
      server. If this is omitted, we attempt to find the value
    from the value of \code{host}.}
    \item{port}{the port number on which the server is listening.
      This is typically 80, the standard HTTP port. However, one can
      specify  this when creating the S server object to
      identify a different port. This is useful when testing
      a server since one can use a user-level port.
      It is left as \code{NA} if not specified to indicate that it was
      not explicitly set to 80.
     }
    \item{s}{the object being created and initialized.
      Having this as an argument allows the caller to specify
      the class of the desired object and supply a partially initialized
      value and still get the ``standard'' initialization for the server
      object.
      \code{className} is computed in the body of the function and this
      mechanism works via lazy evaluation.
      }
}
\note{
  In the future, we will use a \code{SOAPConnection}
  class that builds on the server and maintains a
  connection to the server.
  The URL may get dropped from the server as we can use
  the same basic host and port combination with different
  URLs for different requests. Experience will give us
  a better handle on an appropriate interface.

  Also, we may store a server-specific, default SOAPAction value in the server.
}    
\value{
  An object of class \code{HTTPSOAPServer},
  \code{FTPSOAPServer} or \code{SOAPServer}.
  If the host is specified with an \code{ftp:} or \code{http:}
  prefix, an object of class \code{FTPSOAPServer} or
  \code{HTTPSOAPServer} respectively is returned.
  Otherwise, a generic \code{SOAPServer} is created.
}
\references{
  \url{http://www.w3.org/TR/SOAP/}
  \url{http://www.omegahat.org/SSOAP},
  \url{http://www.omegahat.org/bugs}.
}
\author{Duncan Temple Lang <duncan@wald.ucdavis.edu>}
\seealso{
 \code{\link{.SOAP}}
 \code{\link[base]{$}}
}

\examples{
SOAPServer("www.nanonull.com", "TimeService/TimeService.asmx")
}
\keyword{interface}
\keyword{connection}
